@@ -35,12 +35,11 @@ class RabbitmqPlugin(PorkchopPlugin):
   def get_data(self):
     output = {}
 
-    vhosts = self.get_vhosts()
-    for vhost in vhosts:
+    for vhost in self.get_vhosts():
       queues = self.get_queues(vhost)
       if vhost == '/':
         vhost = 'default'
       if queues:
         output[vhost] = queues
 
-    return {'vhost': output}
+    return output 
